@@ -13,7 +13,7 @@ from pyoperators import (
 from pyoperators.utils import product
 from pyoperators.utils.testing import (
     assert_eq, assert_is_instance, assert_is_none, assert_is_type,
-    assert_same)
+    assert_same, skiptest_unless_module)
 from .common import IdentityOutplaceOperator, assert_inplace_outplace
 
 SHAPES = ((), (1,), (3,), (2, 3), (2, 3, 4))
@@ -238,6 +238,7 @@ def test_sum_operator():
             assert_eq(d, t.T)
 
 
+@skiptest_unless_module('pyfftw')
 def test_symmetric_band_toeplitz_operator():
     def totoeplitz(n, firstrow):
         if isinstance(n, tuple):
